@@ -66,7 +66,14 @@ class xoRedis(Expando):
 		self._namespace = self._rootName
 		# if self._isRoot: # should work the same
 		if self._parent is None:
-			self._redis = RedisClient(host=self._host, port=self._port, db=self._db)
+			if "host" not in kwargs:
+				kwargs["host"] = self._host
+			if "port" not in kwargs:
+				kwargs["port"] = self._port
+			if "db" not in kwargs:
+				kwargs["db"] = self._db
+			# self._redis = RedisClient(host=self._host, port=self._port, db=self._db)
+			self._redis = RedisClient(**kwargs)
 
 		self._pubsub = self._getRoot()._redis.pubsub()
 		self._binded = False
@@ -205,11 +212,10 @@ class xoRedis(Expando):
 		if isinstance(msg, dict) and "type" in msg:
 			if "message" in msg["type"]:
 				# do_something with the message
-				channel = msg["channel"].decode().replace(
-					"/", ".")  # .strip("Redis.")  # .split(".")[-1]
+				channel = msg["channel"].decode() # .strip("Redis.")  # .split(".")[-1]
 				# if channel.startswith(xoRedis._rootName+"."):
-				if channel.startswith(self._rootName+"."):
-					channel = ".".join(channel.split(".")[1:])  # .split(".")[-1]
+				if channel.startswith(self._rootName+"/"):
+					channel = "/".join(channel.split("/")[1:])  # .split(".")[-1]
 				# print("@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@", msg, args, kwargs)
 				# return message
 				# print("@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@")
@@ -227,11 +233,12 @@ class xoRedis(Expando):
 
 					f = self
 					# print("PRE", f._id, "channel:", channel)
-					f = f[channel]
-					# for c in channel.replace("/",".").split("."):
-					# 	# if c not in f:
-					# 	# 	f[c] = xo()
-					# 	f = f[c]
+					# f = f[channel]
+					for c in channel.split("/"):
+						# print("c:",c)
+						# if c not in f:
+						# 	f[c] = xo()
+						f = f[c]
 					# print("POST",f._id)
 					
 					# print("ggggg2")
